@@ -1,7 +1,7 @@
 /*
 **  BounceWindow.h
 **
-**  Copyright (c) 2001, 2002
+**  Copyright (c) 2001, 2002, 2003
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **
@@ -20,34 +20,22 @@
 **  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
+#ifndef _GNUMail_H_BounceWindow
+#define _GNUMail_H_BounceWindow
+
 #import <AppKit/AppKit.h>
 
 @interface BounceWindow : NSWindow
 {
-  NSTextField *toField, *ccField, *bccField;
-  
-  NSButton *icon, *sendButton, *addressesButton, *cancelButton;
-
-  NSPopUpButton *personalProfilePopUpButton;
-  NSPopUpButton *transportMethodPopUpButton;
+  @public
+    NSTextField *toField, *ccField, *bccField;
+    NSButton *sendButton, *addressesButton;
+    NSPopUpButton *accountPopUpButton;
+    NSPopUpButton *transportMethodPopUpButton;
 }
 
 - (void) layoutWindow;
 
-//
-//access/mutation methods
-//
-
-- (NSButton *) icon;
-- (NSButton *) sendButton;
-- (NSButton *) addressesButton;
-- (NSButton *) cancelButton;
-
-- (NSTextField *) toField;
-- (NSTextField *) ccField;
-- (NSTextField *) bccField;
-
-- (NSPopUpButton *) personalProfilePopUpButton;
-- (NSPopUpButton *) transportMethodPopUpButton;
-
 @end
+
+#endif // _GNUMail_H_BounceWindow
