@@ -1,7 +1,7 @@
 /*
 **  ClockController.h
 **
-**  Copyright (c) 2001, 2002
+**  Copyright (c) 2001, 2002, 2003
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **
@@ -20,10 +20,13 @@
 **  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
+#ifndef _GNUMail_H_ClockController
+#define _GNUMail_H_ClockController
+
 #import <AppKit/AppKit.h>
 
-#import "GNUMailBundle.h"
-#import "PreferencesModule.h"
+#include "GNUMailBundle.h"
+#include "PreferencesModule.h"
 
 @interface ClockController : NSObject <GNUMailBundle>
 {
@@ -37,3 +40,5 @@
 }
 
 @end
+
+#endif // _GNUMail_H_ClockController
