@@ -1,7 +1,7 @@
 /*
 **  ComposeView.h
 **
-**  Copyright (c) 2001, 2002
+**  Copyright (c) 2001, 2002, 2003
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **
@@ -19,31 +19,28 @@
 **  along with this program; if not, write to the Free Software
 **  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
+
+#ifndef _GNUMail_H_ComposeView
+#define _GNUMail_H_ComposeView
+
 #import <AppKit/AppKit.h>
 
 @interface ComposeView : NSView
 {
-  id parent;
+  @public
+    NSPopUpButton *replyPopUpButton;
+    NSPopUpButton *forwardPopUpButton;
+    NSTextField *lineWrapLimitField;
+    NSPopUpButton *defaultCharsetPopUpButton;
 
-  NSPopUpButton *replyPopUpButton;
-  NSPopUpButton *forwardPopUpButton;
-
-  NSTextField *lineWrapLimitField;
+  @private
+    id parent;
 }
 
 - (id) initWithParent: (id) theParent;
-
 - (void) layoutView;
 
-//
-// access methods
-//
-
-- (NSPopUpButton *) replyPopUpButton;
-
-- (NSPopUpButton *) forwardPopUpButton;
-
-- (NSTextField *) lineWrapLimitField;
-
 
 @end
+
+#endif // _GNUMail_H_ComposeView
