@@ -1,7 +1,7 @@
 /*
 **  FilteringView.h
 **
-**  Copyright (c) 2001, 2002
+**  Copyright (c) 2001, 2002, 2003
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **
@@ -19,42 +19,35 @@
 **  along with this program; if not, write to the Free Software
 **  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
+
+#ifndef _GNUMail_H_FilteringView
+#define _GNUMail_H_FilteringView
+
 #import <AppKit/AppKit.h>
 
-@class ExtendedTableView;
 @class ExtendedTableColumn;
+@class SwitchTableView;
 
 @interface FilteringView : NSView
 {
-  ExtendedTableView *tableView;
+  @public
+    SwitchTableView *tableView;
+    ExtendedTableColumn *activeColumn;
+    NSTableColumn *rulesColumn;  
 
-  ExtendedTableColumn *rulesColumn;
-  ExtendedTableColumn *activeColumn;
-  
-  NSScrollView *scrollView;
+    NSScrollView *scrollView;
 
-  NSButton *add, *delete, *duplicate, *edit;
-  NSButton *moveUp, *moveDown;
+    NSButton *add, *delete, *duplicate, *edit;
+    NSButton *moveUp, *moveDown;
 
-  id parent;
+  @private
+    id parent;
 }
 
 - (id) initWithParent: (id) theParent;
-
 - (void) layoutView;
-
 - (void) dealloc;
 
-//
-// access methods
-//
-- (NSTableView *) tableView;
-- (NSTableColumn *) rulesColumn;
-- (NSTableColumn *) activeColumn;
-- (NSButton *) add;
-- (NSButton *) delete;
-- (NSButton *) duplicate;
-- (NSButton *) edit;
-- (NSScrollView *) scrollView;
-
 @end
+
+#endif // _GNUMail_H_FilteringView
