@@ -1,7 +1,7 @@
 /*
 **  ReceivingView.h
 **
-**  Copyright (c) 2001
+**  Copyright (c) 2001, 2002, 2003
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **
@@ -19,45 +19,34 @@
 **  along with this program; if not, write to the Free Software
 **  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
+
+#ifndef _GNUMail_H_ReceivingView
+#define _GNUMail_H_ReceivingView
+
 #import <AppKit/AppKit.h>
 
 @interface ReceivingView : NSView
 {
-  NSTextField *mailspoolFileField;
-  NSTextField *minutesField;
-  NSMatrix *matrix;
-  
-  NSButton *mailspoolFileButton;
-  NSButton *transferFromMailspoolFile;
-  NSButton *compactMailboxButton;
-  NSButton *showFilterPanelButton;
+  //NSTextField *minutesField;
+  //NSStepper *stepper;
+  //NSMatrix *matrix;
 
-  NSTableView *tableView;
+  @public
+    NSButton *showFilterPanelButton;
+    NSButton *showNoNewMessagesPanelButton;
+    NSButton *openMailboxAfterTransfer;
+    NSButton *playSoundButton;
+    NSTextField *pathToSoundField;
+    NSButton *chooseFileButton;
   
-  id parent;
+  @private
+   id parent;
 }
 
 - (id) initWithParent: (id) theParent;
-
 - (void) layoutView;
-
 - (void) dealloc;
 
-
-//
-// access methods
-//
-
-- (NSTextField *) mailspoolFileField;
-- (NSTextField *) minutesField;
-
-- (NSMatrix *) matrix;
-
-- (NSButton *) mailspoolFileButton;
-- (NSButton *) transferFromMailspoolFile;
-- (NSButton *) compactMailboxButton;
-- (NSButton *) showFilterPanelButton;
-
-- (NSTableView *) tableView;
-
 @end
+
+#endif // _GNUMail_H_ReceivingView
