@@ -1,7 +1,7 @@
 /*
 **  ViewingView.h
 **
-**  Copyright (c) 2001, 2002
+**  Copyright (c) 2001, 2002, 2003
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **
@@ -19,41 +19,29 @@
 **  along with this program; if not, write to the Free Software
 **  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
+
+#ifndef _GNUMail_H_ViewingView
+#define _GNUMail_H_ViewingView
+
 #import <AppKit/AppKit.h>
 
 @interface ViewingView : NSView
 {  
-  NSButton *highlightURLs;
-
-  NSTableView *tableView;
-  NSTextField *keyField;
-
-  NSButton *showAllHeaders;
-  NSButton *hideDeletedMessages;
+  @public
+    NSButton *highlightURLs;
+    NSButton *hideDeletedMessages;
+    NSButton *hideReadMessages;
   
-  NSMatrix *matrix;
+    NSMatrix *matrix;
+    NSPopUpButton *doubleClickPopUpButton;
 
-  id parent;
+  @private
+    id parent;
 }
 
 - (id) initWithParent: (id) theParent;
-
 - (void) layoutView;
 
-//
-// access methods
-//
-
-- (NSButton *) highlightURLs;
-
-- (NSTableView *) tableView;
-
-- (NSTextField *) keyField;
-
-- (NSButton *) showAllHeaders;
-
-- (NSButton *) hideDeletedMessages;
-
-- (NSMatrix *) matrix;
-
 @end
+
+#endif // _GNUMail_H_ViewingView
