@@ -20,39 +20,39 @@
 **  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
+#ifndef _GNUMail_H_ViewingViewController
+#define _GNUMail_H_ViewingViewController
+
 #import <AppKit/AppKit.h>
 
-#import "PreferencesModule.h"
+#include "PreferencesModule.h"
 
 @interface ViewingViewController : NSObject <PreferencesModule>
 {
   // Outlets
   IBOutlet id view;
   
+  IBOutlet NSButton *hideDeletedMessages;
+  IBOutlet NSButton *hideReadMessages;
   IBOutlet NSButton *highlightURLs;
 
-  IBOutlet NSTableView *tableView;
-  IBOutlet NSTextField *keyField;
-
-  IBOutlet NSButton *showAllHeaders;
-  IBOutlet NSButton *hideDeletedMessages;
+  IBOutlet NSPopUpButton *doubleClickPopUpButton;
 
   IBOutlet NSMatrix *matrix;
 
-  // Other ivars
-  NSMutableArray *shownHeaders;
+  // Values
+  struct {
+    NSMutableArray *shownHeaders;
+    int            showAllHeadersButtonState;
+  } _values;
 }
 
 
 //
 // action methods
 //
-- (IBAction) addDefaults: (id) sender;
-- (IBAction) addShown: (id) sender;
-- (IBAction) removeShown: (id) sender; 
-
-- (IBAction) moveUp: (id) sender;
-- (IBAction) moveDown: (id) sender;
-
+- (IBAction) headersButtonClicked: (id) sender;
 
 @end
+
+#endif // _GNUMail_H_ViewingViewController
