@@ -1,7 +1,7 @@
 /*
 **  ExtendedAttachmentCell.h
 **
-**  Copyright (c) 2001
+**  Copyright (c) 2001, 2002, 2003
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **
@@ -20,6 +20,9 @@
 **  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
+#ifndef _GNUMail_H_ExtendedAttachmentCell
+#define _GNUMail_H_ExtendedAttachmentCell
+
 #import <AppKit/AppKit.h>
 
 @class Part;
@@ -42,3 +45,5 @@
 - (void) setPart: (Part *) thePart;
 
 @end
+
+#endif // _GNUMail_H_ExtendedAttachmentCell
