@@ -1,7 +1,7 @@
 /*
 **  ExtendedCell.h
 **
-**  Copyright (c) 2001
+**  Copyright (c) 2001, 2002, 2003
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **
@@ -20,6 +20,9 @@
 **  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
+#ifndef _GNUMail_H_ExtendedCell
+#define _GNUMail_H_ExtendedCell
+
 #import <AppKit/AppKit.h>
 
 @class Flags;
@@ -29,13 +32,13 @@
   // ivars
   NSImage *answered_flag, *mime_flag, *new_flag;
 
-
   Flags *flags;
   BOOL isMimeMessage;
 }
 
 - (void) setFlags: (Flags *) theFlags;
-
 - (void) setIsMimeMessage: (BOOL) aBOOL;
 
 @end
+
+#endif // _GNUMail_H_ExtendedCell
