@@ -1,7 +1,7 @@
 /*
 **  FindWindow.h
 **
-**  Copyright (c) 2001
+**  Copyright (c) 2001, 2002, 2003
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **
@@ -20,33 +20,26 @@
 **  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
+#ifndef _GNUMail_H_FindWindow
+#define _GNUMail_H_FindWindow
+
 #import <AppKit/AppKit.h>
-#import "LabelWidget.h"
+
+#include "LabelWidget.h"
 
 @interface FindWindow: NSPanel
 {
-  NSTextField *findField;
-  NSTextField *replaceWithField;
-  LabelWidget *foundLabel;
-  NSMatrix *matrix;
-  NSButton *ignoreCaseButton;
-  NSButton *regularExpressionButton;
+  @public
+    NSTextField *findField;
+    LabelWidget *foundLabel;
+    NSMatrix *matrix;
+    NSButton *ignoreCaseButton;
+    NSButton *regularExpressionButton;
 }
 
 - (void) dealloc;
-
 - (void) layoutWindow;
 
-//
-// access/mutation methods
-//
-
-- (NSTextField *) findField;
-- (NSTextField *) replaceWithField;
-- (NSButton *) ignoreCaseButton;
-- (NSButton *) regularExpressionButton;
-- (LabelWidget *) foundLabel;
-- (NSMatrix *) matrix;
-
 @end
 
+#endif // _GNUMail_H_FindWindow
