@@ -1,10 +1,10 @@
 /*
 **  LabelWidget.h
 **
-**  Copyright (c) 2001, 2002
+**  Copyright (c) 2001, 2002, 2003
 **
 **  Author: Jonathan B. Leffert <jonathan@leffert.net>
-**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
+**           Ludovic Marcotte <ludovic@Sophos.ca>
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
@@ -21,6 +21,9 @@
 **  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
+#ifndef _GNUMail_H_LabelWidget
+#define _GNUMail_H_LabelWidget
+
 #import <AppKit/AppKit.h>
 
 @interface LabelWidget: NSTextField
@@ -35,3 +38,5 @@
 + (id) labelWidgetWithFrame: (NSRect) theFrame label: (NSString *) theLabel alignment: (int) theAlignment;
 
 @end
+
+#endif // _GNUMail_H_LabelWidget
