@@ -1,7 +1,7 @@
 /*
 **  LocalMailDelivery.h
 **
-**  Copyright (c) 2001, 2002
+**  Copyright (c) 2001, 2002, 2003
 **
 **  Author: Jonathan B. Leffert <jonathan@leffert.net>
 **          Ludovic Marcotte <ludovic@Sophos.ca>
@@ -21,6 +21,9 @@
 **  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
 
+#ifndef _GNUMail_H_LocalMailDelivery
+#define _GNUMail_H_LocalMailDelivery
+
 #import <Foundation/Foundation.h>
   
 @interface LocalMailDelivery: NSObject
@@ -28,24 +31,24 @@
   NSString *pathToSpool;
 }
  
-- (id) init;
 - (id) initWithPathToSpool: (NSString *) thePath;
- 
 - (void) dealloc;
 
+
 //
 // general methods
 //
-
 - (BOOL) needToReadMailspool: (NSString *) theMailspool;
 - (NSArray *) readContentsOfMailspool: (NSString *) theMailspool;
 - (NSArray *) messagesFromMailspoolFile;
+
  
 //
 // access/mutation methods
 //
-
 - (NSString *) pathToSpool;
 - (void) setPathToSpool: (NSString *) thePath;
  
 @end
+
+#endif // _GNUMail_H_LocalMailDelivery
