@@ -1,7 +1,7 @@
 /*
 **  MailboxManager.h
 **
-**  Copyright (c) 2001, 2002
+**  Copyright (c) 2001, 2002, 2003
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **
@@ -19,29 +19,26 @@
 **  along with this program; if not, write to the Free Software
 **  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
+
+#ifndef _GNUMail_H_MailboxManager
+#define _GNUMail_H_MailboxManager
+
 #import <AppKit/AppKit.h>
 
+@class ExtendedOutlineView;
+
 @interface MailboxManager : NSPanel
 {
-  NSTableColumn *mailboxColumn, *sizeColumn, *messagesColumn;
-  NSOutlineView *outlineView;
-
-  NSPopUpButton *transfer;
-  NSButton *openOnStartup;
+  @public
+    NSTableColumn *mailboxColumn, *messagesColumn;
+    ExtendedOutlineView *outlineView;
+    NSScrollView *scrollView;  
+    NSButton *move, *copy;
 }
 
 - (void) layoutWindow;
-
 - (void) dealloc;
 
-//
-// access/mutation methods
-//
-
-- (NSPopUpButton *) transfer;
-
-- (NSOutlineView *) outlineView;
-
-- (NSButton *) openOnStartup;
-
 @end
+
+#endif // _GNUMail_H_MailboxManager
