@@ -1,7 +1,7 @@
 /*
 **  NewMailboxPanel.h
 **
-**  Copyright (c) 2001
+**  Copyright (c) 2001, 2002, 2003
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **
@@ -19,15 +19,25 @@
 **  along with this program; if not, write to the Free Software
 **  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
+
+#ifndef _GNUMail_H_NewMailboxPanel
+#define _GNUMail_H_NewMailboxPanel
+
 #import <AppKit/AppKit.h>
 
+@class LabelWidget;
+
 @interface NewMailboxPanel : NSPanel
 {
-  NSTextField *mailboxNameField;
+  @public
+    LabelWidget *mailboxNameLabel;
+    NSTextField *mailboxNameField;
+    NSPopUpButton *popUpButton;
 }
 
+- (void) dealloc;
 - (void) layoutPanel;
 
-- (NSTextField *) mailboxNameField;
-
 @end
+
+#endif // _GNUMail_H_NewMailboxPanel
