@@ -1,7 +1,7 @@
 /*
 **  PreferencesWindow.h
 **
-**  Copyright (c) 2001, 2002
+**  Copyright (c) 2001, 2002, 2003
 **
 **  Author: Ludovic Marcotte <ludovic@Sophos.ca>
 **
@@ -19,22 +19,25 @@
 **  along with this program; if not, write to the Free Software
 **  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
+
+#ifndef _GNUMail_H_PreferencesWindow
+#define _GNUMail_H_PreferencesWindow
+
 #import <AppKit/AppKit.h>
 
 @interface PreferencesWindow : NSWindow
 {
-  NSMatrix *matrix;
-  NSBox *box;
+  @public
+    NSScrollView *scrollView;
+    NSMatrix *matrix;
+    NSBox *box;
+    NSButton *expert;
 }
 
 - (void) layoutWindow;
-
 - (void) dealloc;
 
-//
-// access/mutation methods
-//
-- (NSMatrix *) matrix;
-- (NSBox *) box;
 
 @end
+
+#endif // _GNUMail_H_PreferencesWindow
